@@ -21,12 +21,11 @@ from hitrustai_lab.orm.Tables.ModelPerformance import create_model_performance,
 dict_init_arg = {
     "list_y_test": list,
     "list_y_score": np.array,
-    "customer_id_lst": str,
-    "training_id_lst": str,
+    # "customer_id_lst": str,
+    # "training_id_lst": str,
     "model_id_lst": str,
-    "profile_id_lst": str,
-    "tag_lst": str,
-    "training_start_time_lst": str,
+    # "profile_id_lst": str,
+    # "tag_lst": str,
     "total_training_time_lst": int,
     "training_start_time_lst": datetime,
     "training_end_time_lst": datetime,
@@ -54,11 +53,11 @@ class TrainModelToSQl:
         try:
             result = mp.performance_output(dict_init_arg["list_y_test"], dict_init_arg["list_y_score"])
             result = {
-                'customer_id': dict_init_arg["customer_id_lst"],
-                'training_id': dict_init_arg["training_id_lst"],
+                # 'customer_id': dict_init_arg["customer_id_lst"],
+                # 'training_id': dict_init_arg["training_id_lst"],
                 'model_id': dict_init_arg["model_id_lst"],
-                'profile_id': dict_init_arg["profile_id_lst"],
-                'tag': dict_init_arg["tag_lst"],
+                # 'profile_id': dict_init_arg["profile_id_lst"],
+                # 'tag': dict_init_arg["tag_lst"],
                 'model_name': dict_init_arg["model_id_lst"] + "-" + "".join(re.findall(r'\d+', str(datetime.datetime.now()))),
                 'training_start_time': dict_init_arg["training_start_time_lst"],
                 'training_end_time': dict_init_arg["training_end_time_lst"],
@@ -94,11 +93,11 @@ class TrainModelToSQl:
             }
         except Exception:
             result = {
-                'customer_id': dict_init_arg["customer_id_lst"],
-                'training_id': dict_init_arg["training_id_lst"],
+                # 'customer_id': dict_init_arg["customer_id_lst"],
+                # 'training_id': dict_init_arg["training_id_lst"],
                 'model_id': dict_init_arg["model_id_lst"],
-                'profile_id': dict_init_arg["profile_id_lst"],
-                'tag': dict_init_arg["tag_lst"],
+                # 'profile_id': dict_init_arg["profile_id_lst"],
+                # 'tag': dict_init_arg["tag_lst"],
                 'model_name': dict_init_arg["model_id_lst"] + "-" + "".join(re.findall(r'\d+', str(datetime.datetime.now()))),
                 'training_start_time': "2000-01-01 00:00:00",
                 'training_end_time': "2000-01-01 00:00:00",
@@ -172,48 +171,47 @@ class TrainModelToSQl:
 
 
 class GetConfArg:
+    def tryerr(self, cnf, key):
+        try:
+            cnf_read = cnf(key)
+            return cnf_read
+        except Exception as e:
+            self.err_return_code = "0105"
+            self.err_reason = self.model_name + "-" + str(e.args[0])
+            return ""
+    
     def read_train_conf_env(self):
         config = AutoConfig(search_path=os.getcwd() + "/env")
-        # check docker environment exist
-        CUSTOMER_ID = os.environ.get('CUSTOMER_ID')
-        MODEL_ID = os.environ.get('MODEL_ID')
-        TRAINING_ID = os.environ.get('TRAINING_ID')
-        KAFKA_TOPIC = os.environ.get('KAFKA_TOPIC')
-
-        # check service .env file exist
-        kafka_node = config('KAFKA_N', default='0')
-        bootstrap_servers = []
-        for i in range(int(kafka_node)):
-            host = config('KAFKA_HOST_' + str(i + 1), default='')
-            port = config('KAFKA_PORT_' + str(i + 1), default='')
-            if host == "" or port == "":
-                self.init_logger.error('Error: Invalid variable in env. Expected keys [KAFKA_HOST, KAFKA_PORT]')
-                os.kill(0, 4)
-            bootstrap_servers.append(host + ":" + port)
-
-        self.appollo_info = {
-            "servers": bootstrap_servers,
-            "customer_id": CUSTOMER_ID,
-            "model_id": MODEL_ID,
-            "training_id": TRAINING_ID,
-            "topic": KAFKA_TOPIC,
-            "BATCH_SIZE": int(config('Chunksize', default='100000')),
-            "dataset_path": config('SOURCE_PATH_DATASET', default=''),
-            "kg_path": config('SOURCE_PATH_KNOWLEDGE', default=''),
-            "lib_path": config('SOURCE_PATH_LIB', default=''),
-            "KAFKA_USE": config('KAFKA_USE', default=''),
-        }
-
         db_pass = config('DB_PASS', default='')
         password = decrypt_passwd(self.passwd_so_name, db_pass)
+
         self.SQLALCHEMY_DATABASE_URI = '{}://{}:{}@{}:{}/{}'.format(
-            config('DB_ENGINE', default='mysql+pymysql'),
-            config('DB_USERNAME', default='test'),
+            config('DB_ENGINE', default=''),
+            config('DB_USERNAME', default=''),
             password,
-            config('DB_HOST', default='127.0.0.1'),
-            config('DB_PORT', default=3306),
-            config('DB_NAME', default='testdb')
+            config('DB_HOST', default=''),
+            config('DB_PORT', default=''),
+            config('DB_NAME', default='')
         )
+        self.tryerr(config, 'TRUE_LABEL_COLUMN')
+        self.appollo_info = {
+            # "customer_id": config('CUSTOMER_ID', default=''),
+            # "PROFILE_ID": config('PROFILE_ID', default=''),
+            # "tag": config('tag', default=''),
+            # "training_id": config('TRAINING_ID', default=''),
+
+            "model_id": config('MODEL_ID', default=''),
+            "BATCH_SIZE": int(config('BATCH_SIZE', default=6000)),
+            "TRUE_LABEL_COLUMN": self.tryerr(config, 'TRUE_LABEL_COLUMN'),
+            "kg_path": config('SOURCE_PATH_KNOWLEDGE', default='./data/kg/'),
+            "lib_path": config('SOURCE_PATH_LIB', default='./data/lib/'),
+            "DB_ENGINE": self.tryerr(config, 'DB_ENGINE'),
+            "DB_USERNAME": self.tryerr(config, 'DB_USERNAME'),
+            "DB_PASS": password,
+            "DB_HOST": self.tryerr(config, 'DB_HOST'),
+            "DB_PORT": self.tryerr(config, 'DB_PORT'),
+            "DB_NAME": self.tryerr(config, 'DB_NAME')
+        }
 
     def read_train_conf_apollo(self):
         config = AutoConfig(search_path=os.getcwd() + "/env")
@@ -233,17 +231,6 @@ class GetConfArg:
             secret=APOLLO_SECRET,
             change_listener=check_apollo_change)
 
-        # check service .env file exist
-        KAFKA_N = get_apollo_value(apollo_client, "KAFKA_NODE", APOLLO_NAMESPACE_INF)
-        KAFKA_N = KAFKA_N.split(",")
-        # kafka_node = len(KAFKA_N)
-        bootstrap_servers = []
-        for ip in KAFKA_N:
-            host, port = ip.split(":")
-            if host == "" or port == "":
-                self.init_logger.error('Error: Invalid variable in env. Expected keys [KAFKA_HOST, KAFKA_PORT]')
-                os.kill(0, 4)
-            bootstrap_servers.append(host + ":" + port)
         db_pass = get_apollo_value(apollo_client, "DB_PASS", APOLLO_NAMESPACE_INF)
 
         password = decrypt_passwd(self.passwd_so_name, db_pass)
@@ -256,22 +243,17 @@ class GetConfArg:
             get_apollo_value(apollo_client, "DB_NAME", APOLLO_NAMESPACE_INF)
         )
         self.appollo_info = {
-            "servers": bootstrap_servers,
-            "customer_id": get_apollo_value(apollo_client, "CUSTOMER_ID", APOLLO_NAMESPACE_MODAL),
-            "tag": get_apollo_value(apollo_client, "tag", APOLLO_NAMESPACE_MODAL),
-            "PROFILE_ID": get_apollo_value(apollo_client, "PROFILE_ID", APOLLO_NAMESPACE_MODAL),
+            # "customer_id": get_apollo_value(apollo_client, "CUSTOMER_ID", APOLLO_NAMESPACE_MODAL),
+            # "tag": get_apollo_value(apollo_client, "tag", APOLLO_NAMESPACE_MODAL),
+            # "PROFILE_ID": get_apollo_value(apollo_client, "PROFILE_ID", APOLLO_NAMESPACE_MODAL),
+            # "training_id": get_apollo_value(apollo_client, "TRAINING_ID", APOLLO_NAMESPACE_MODAL),
+            # "topic": get_apollo_value(apollo_client, "TRAINING_ID", APOLLO_NAMESPACE_MODAL),
+
             "model_id": get_apollo_value(apollo_client, "MODEL_ID", APOLLO_NAMESPACE_MODAL),
-            "training_id": get_apollo_value(apollo_client, "TRAINING_ID", APOLLO_NAMESPACE_MODAL),
-            "topic": get_apollo_value(apollo_client, "TRAINING_ID", APOLLO_NAMESPACE_MODAL),
             "BATCH_SIZE": int(get_apollo_value(apollo_client, "BATCH_SIZE", APOLLO_NAMESPACE_MODAL)),
             "TRUE_LABEL_COLUMN": get_apollo_value(apollo_client, "TRUE_LABEL_COLUMN", APOLLO_NAMESPACE_MODAL),
-
-            # "dataset_path": get_apollo_value(apollo_client, "SOURCE_PATH_DATASET", APOLLO_NAMESPACE_MODAL),
             "kg_path": config('SOURCE_PATH_KNOWLEDGE'),
             "lib_path": config('SOURCE_PATH_LIB'),
-            # "kg_path": get_apollo_value(apollo_client, "SOURCE_PATH_KNOWLEDGE", APOLLO_NAMESPACE_MODAL),
-            # "lib_path": get_apollo_value(apollo_client, "SOURCE_PATH_LIB", APOLLO_NAMESPACE_MODAL),
-            # "KAFKA_USE": get_apollo_value(apollo_client, "KAFKA_USE", APOLLO_NAMESPACE_MODAL),
             "DB_ENGINE": get_apollo_value(apollo_client, "DB_ENGINE", APOLLO_NAMESPACE_INF),
             "DB_USERNAME": get_apollo_value(apollo_client, "DB_USERNAME", APOLLO_NAMESPACE_INF),
             "DB_PASS": password,
@@ -283,16 +265,15 @@ class GetConfArg:
 
 class HitrustaiTrainTemple(GetConfArg):
     def __init__(self, dict_model, init_logger, passwd_so_name="./data/passwd.so", model_name="fraud detect"):
+        self.err_reason = ""
+        self.err_return_code = "9909"
         self.dict_model = dict_model
         self.init_logger = init_logger
         self.passwd_so_name = passwd_so_name
         self.model_name = model_name
         self.dict_init_arg = None
         self.template_output_txt = '''
-=================================================
 INFO_MODEL_NAME: %s
-INFO_TRAINING_ID : %s
-INFO_CUSTOMER_ID: %s
 INFO_MODEL_ID: %s
 DATA_START_DATE: %s
 DATA_END_DATE: %s
@@ -303,16 +284,35 @@ TRAINING_RETURN_CODE : %s
 TRAINING_REASON : %s
         '''
 
+    def err_template(self):
+        self.training_start_time_lst = "2000-01-01 00:00:00"
+        self.total_training_time_lst = -1
+        self.training_end_time_lst = "2000-01-01 00:00:00"
+        self.DATA_START_DATE = "2000-01-01 00:00:00"
+        self.DATA_END_DARE = "2000-01-01 00:00:00"
+        self.DATA_TOTAL_ROW = -1
+        self.dict_init_arg = self.error_arg_dict()
+        self.dict_init_arg["reason"] = self.err_reason
+
     def error_arg_dict(self):
+        try:
+            true_lable_name = self.dict_model.true_lable_name
+        except Exception:
+            true_lable_name = None
+        try:
+            model_id = self.appollo_info.get("model_id")
+        except Exception:
+            model_id = None
+        
         dict_init_arg = {
             "list_y_test": [],
             # "list_y_score": np.array(self.df["total_score_fd7"]),
             "list_y_score": [],
-            "customer_id_lst": self.appollo_info["customer_id"],
-            "training_id_lst": self.appollo_info["training_id"],
-            "model_id_lst": self.appollo_info["model_id"],
-            "profile_id_lst": self.appollo_info["PROFILE_ID"],
-            "tag_lst": self.appollo_info["tag"],
+            # "customer_id_lst": self.appollo_info["customer_id"],
+            # "training_id_lst": self.appollo_info["training_id"],
+            "model_id_lst": model_id,
+            # "profile_id_lst": self.appollo_info["PROFILE_ID"],
+            # "tag_lst": self.appollo_info["tag"],
             "training_start_time_lst": self.training_start_time_lst,
             "total_training_time_lst": self.total_training_time_lst,
 
@@ -324,11 +324,10 @@ TRAINING_REASON : %s
             "number_of_positive_samples_in_training_data": -1,
             "number_of_negative_samples_in_training_data": -1,
             "number_of_validation_data": -1,
-            "true_label_column_lst": self.dict_model.true_lable_name,
+            "true_label_column_lst": true_lable_name,
             "number_of_positive_samples_in_validation_data": -1,
             "number_of_negative_samples_in_validation_data": -1,
-            "return_code": self.dict_report["return_code"],
-            "reason": self.dict_report["reason"]
+            "return_code": self.err_return_code,
         }
         return dict_init_arg
 
@@ -337,11 +336,11 @@ TRAINING_REASON : %s
         dict_init_arg = {
             "list_y_test": list,
             "list_y_score": np.array,
-            "customer_id_lst": str,
-            "training_id_lst": str,
+            # "customer_id_lst": str,
+            # "training_id_lst": str,
             "model_id_lst": str,
-            "profile_id_lst": str,
-            "tag_lst": str,
+            # "profile_id_lst": str,
+            # "tag_lst": str,
             "training_start_time_lst": str,
             "total_training_time_lst": int,
             "training_start_time_lst": datetime,
@@ -363,11 +362,11 @@ TRAINING_REASON : %s
             "list_y_test": list(self.dict_model.df[self.dict_model.true_lable_name]),
             # "list_y_score": np.array(self.df["total_score_fd7"]),
             "list_y_score": np.array,
-            "customer_id_lst": self.appollo_info["customer_id"],
-            "training_id_lst": self.appollo_info["training_id"],
+            # "customer_id_lst": self.appollo_info["customer_id"],
+            # "training_id_lst": self.appollo_info["training_id"],
             "model_id_lst": self.appollo_info["model_id"],
-            "profile_id_lst": self.appollo_info["PROFILE_ID"],
-            "tag_lst": self.appollo_info["tag"],
+            # "profile_id_lst": self.appollo_info["PROFILE_ID"],
+            # "tag_lst": self.appollo_info["tag"],
             "training_start_time_lst": self.training_start_time_lst,
             "total_training_time_lst": self.total_training_time_lst,
 
@@ -402,38 +401,36 @@ TRAINING_REASON : %s
             self.DATA_START_DATE = self.dict_model.DATA_START_DATE
             self.DATA_END_DARE = self.dict_model.DATA_END_DARE
             self.DATA_TOTAL_ROW = self.dict_model.DATA_TOTAL_ROW
-
-            self.dict_init_arg = self.input_arg_dict()
+            if self.dict_report["return_code"] != "4008":
+                self.err_reason = self.dict_report["reason"]
+                self.err_template()
+            else:
+                self.dict_init_arg = self.input_arg_dict()
 
         except Exception as e:
-            self.training_start_time_lst = "2000-01-01 00:00:00"
-            self.total_training_time_lst = -1
-            self.training_end_time_lst = "2000-01-01 00:00:00"
-            self.DATA_START_DATE = "2000-01-01 00:00:00"
-            self.DATA_END_DARE = "2000-01-01 00:00:00"
-            self.DATA_TOTAL_ROW = -1
-            
-            self.dict_init_arg = self.error_arg_dict()
-            self.dict_init_arg["reason"] = e.args[0]
-            if self.dict_report["return_code"] == "4001":
-                self.dict_init_arg["return_code"] = "9914"
+            self.err_reason = "FraudDetect-" + e.args[0]
+            self.err_template()
 
     def insert_db(self, table_name, dict_add_column=None):
-        tmts = TrainModelToSQl(
-            host=self.appollo_info["DB_HOST"],
-            port=self.appollo_info["DB_PORT"],
-            user=self.appollo_info["DB_USERNAME"],
-            passwd=self.appollo_info["DB_PASS"],
-            db=self.appollo_info["DB_NAME"],
-            table_name=table_name
-        )
-        tmts.insert_db(data=self.dict_init_arg, dict_add_column=dict_add_column)
+        try:
+            tmts = TrainModelToSQl(
+                host=self.appollo_info["DB_HOST"],
+                port=self.appollo_info["DB_PORT"],
+                user=self.appollo_info["DB_USERNAME"],
+                passwd=self.appollo_info["DB_PASS"],
+                db=self.appollo_info["DB_NAME"],
+                table_name=table_name
+            )
+            tmts.insert_db(data=self.dict_init_arg, dict_add_column=dict_add_column)
+        except Exception as e:
+            self.dict_init_arg["return_code"] = "0105"
+            self.dict_init_arg["reason"] = self.model_name + "-" + e.args[0]
 
     def output_txt(self, model_name="Fraud Detect", path='./data/lib/output.txt'):
         output_txt = self.template_output_txt % (
             model_name,
-            self.dict_init_arg["training_id_lst"],
-            self.dict_init_arg["customer_id_lst"],
+            # self.dict_init_arg["training_id_lst"],
+            # self.dict_init_arg["customer_id_lst"],
             self.dict_init_arg["model_id_lst"],
             self.dict_init_arg["training_data_start_date"],
             self.dict_init_arg["training_data_end_date"],
@@ -443,7 +440,7 @@ TRAINING_REASON : %s
             self.dict_init_arg["return_code"],
             self.dict_init_arg["reason"],
         )
-        with open(path, 'a') as f:
+        with open(path, 'w') as f:
             f.write(output_txt + "\n")
 
 
